@@ -562,7 +562,9 @@ module Sass
       def supports_operator
         cond = supports_condition_in_parens
         return unless cond
-        while (op = tok(/and|or/i))
+        re = /and|or/i
+        while (op = tok(re))
+          re = /#{op}/i
           ss
           cond = Sass::Supports::Operator.new(
             cond, expr!(:supports_condition_in_parens), op)
@@ -586,11 +588,6 @@ module Sass
         end
       end
 
-      def supports_declaration_condition
-        return unless tok(/\(/); ss
-        supports_declaration_body
-      end
-
       def supports_interpolation
         interp = interpolation
         return unless interp
@@ -808,6 +805,8 @@ module Sass
       def almost_any_value_token
         tok(%r{
           (
+            \\.
+          |
             (?!url\()
             [^"'/\#!;\{\}] # "
           |
