@@ -30,8 +30,7 @@ SCSS
   end
 
   def test_empty_directive
-    assert_scss_to_sass "@media screen", "@media screen {}"
-    assert_scss_to_scss "@media screen {}"
+    assert_renders "@media screen", "@media screen {}"
   end
 
   def test_empty_control_directive
@@ -44,6 +43,7 @@ foo bar
   baz bang
     baz: bang
     bip: bop
+
   blat: boo
 SASS
 foo bar {
@@ -51,6 +51,7 @@ foo bar {
     baz: bang;
     bip: bop;
   }
+
   blat: boo;
 }
 SCSS
@@ -287,7 +288,15 @@ foo bar {
 }
 SCSS
 
-    assert_sass_to_scss <<SCSS, <<SASS
+    assert_renders <<SASS, <<SCSS
+// foo
+// bar
+//   baz
+// bang
+
+foo bar
+  a: b
+SASS
 // foo
 // bar
 //   baz
@@ -297,31 +306,27 @@ foo bar {
   a: b;
 }
 SCSS
-// foo
-// bar
-//   baz
-// bang
-
-foo bar
-  a: b
-SASS
   end
 
   def test_nested_silent_comments
     assert_renders <<SASS, <<SCSS
 foo
   bar: baz
+
   // bip bop
   // beep boop
   bang: bizz
+
   // bubble bubble
   // toil trouble
 SASS
 foo {
   bar: baz;
+
   // bip bop
   // beep boop
   bang: bizz;
+
   // bubble bubble
   // toil trouble
 }
@@ -330,10 +335,12 @@ SCSS
     assert_sass_to_scss <<SCSS, <<SASS
 foo {
   bar: baz;
+
   // bip bop
   // beep boop
   //   bap blimp
   bang: bizz;
+
   // bubble bubble
   // toil trouble
   //    gorp
@@ -341,10 +348,12 @@ foo {
 SCSS
 foo
   bar: baz
+
   // bip bop
      beep boop
        bap blimp
   bang: bizz
+
   // bubble bubble
     toil trouble
        gorp
@@ -444,17 +453,21 @@ SCSS
     assert_renders <<SASS, <<SCSS
 foo
   bar: baz
+
   /* bip bop
    * beep boop
   bang: bizz
+
   /* bubble bubble
    * toil trouble
 SASS
 foo {
   bar: baz;
+
   /* bip bop
    * beep boop */
   bang: bizz;
+
   /* bubble bubble
    * toil trouble */
 }
@@ -463,10 +476,12 @@ SCSS
     assert_sass_to_scss <<SCSS, <<SASS
 foo {
   bar: baz;
+
   /* bip bop
    * beep boop
    *   bap blimp */
   bang: bizz;
+
   /* bubble bubble
    * toil trouble
    *    gorp */
@@ -474,10 +489,12 @@ foo {
 SCSS
 foo
   bar: baz
+
   /* bip bop
      beep boop
        bap blimp
   bang: bizz
+
   /* bubble bubble
     toil trouble
        gorp
@@ -614,10 +631,12 @@ SASS
     assert_renders <<SASS, <<SCSS
 foo
   @debug 12px
+
   bar: baz
 SASS
 foo {
   @debug 12px;
+
   bar: baz;
 }
 SCSS
@@ -627,10 +646,12 @@ SCSS
     assert_renders <<SASS, <<SCSS
 foo
   @error "oh no!"
+
   bar: baz
 SASS
 foo {
   @error "oh no!";
+
   bar: baz;
 }
 SCSS
@@ -640,10 +661,12 @@ SCSS
     assert_renders <<SASS, <<SCSS
 foo
   @foo #bar "baz"
+
   bar: baz
 SASS
 foo {
   @foo #bar "baz";
+
   bar: baz;
 }
 SCSS
@@ -675,6 +698,7 @@ foo
   @foo #bar "baz"
     #blat
       a: b
+
     .bang
       c: d
       e: f
@@ -686,6 +710,7 @@ foo {
     #blat {
       a: b;
     }
+
     .bang {
       c: d;
       e: f;
@@ -702,11 +727,14 @@ SCSS
 foo
   @foo #bar "baz"
     g: h
+
     #blat
       a: b
+
     .bang
       c: d
       e: f
+
     i: j
 
   bar: baz
@@ -714,13 +742,16 @@ SASS
 foo {
   @foo #bar "baz" {
     g: h;
+
     #blat {
       a: b;
     }
+
     .bang {
       c: d;
       e: f;
     }
+
     i: j;
   }
 
@@ -742,6 +773,7 @@ SCSS
 foo
   @for $a from $b to $c
     a: b
+
   @for $c from 1 to 16
     d: e
     f: g
@@ -750,6 +782,7 @@ foo {
   @for $a from $b to $c {
     a: b;
   }
+
   @for $c from 1 to 16 {
     d: e;
     f: g;
@@ -763,6 +796,7 @@ SCSS
 foo
   @while flaz($a + $b)
     a: b
+
   @while 1
     d: e
     f: g
@@ -771,6 +805,7 @@ foo {
   @while flaz($a + $b) {
     a: b;
   }
+
   @while 1 {
     d: e;
     f: g;
@@ -784,6 +819,7 @@ SCSS
 foo
   @if $foo or $bar
     a: b
+
   @if $baz
     d: e
   @else if $bang
@@ -795,6 +831,7 @@ foo {
   @if $foo or $bar {
     a: b;
   }
+
   @if $baz {
     d: e;
   }
@@ -940,10 +977,12 @@ SCSS
     assert_renders <<SASS, <<SCSS
 .foo
   @extend .bar
+
   @extend .baz:bang
 SASS
 .foo {
   @extend .bar;
+
   @extend .baz:bang;
 }
 SCSS
@@ -1042,10 +1081,12 @@ SASS
     assert_renders <<SASS, <<SCSS
 foo
   +foo-bar
+
   a: blip
 SASS
 foo {
   @include foo-bar;
+
   a: blip;
 }
 SCSS
@@ -1055,10 +1096,12 @@ SCSS
     assert_renders <<SASS, <<SCSS
 foo
   +foo-bar(12px, "blaz")
+
   a: blip
 SASS
 foo {
   @include foo-bar(12px, "blaz");
+
   a: blip;
 }
 SCSS
@@ -1068,12 +1111,16 @@ SCSS
     assert_renders <<SASS, <<SCSS
 foo
   +foo-bar(12px, "blaz", $blip: blap, $bloop: blop)
+
   +foo-bar($blip: blap, $bloop: blop)
+
   a: blip
 SASS
 foo {
   @include foo-bar(12px, "blaz", $blip: blap, $bloop: blop);
+
   @include foo-bar($blip: blap, $bloop: blop);
+
   a: blip;
 }
 SCSS
@@ -1083,10 +1130,12 @@ SCSS
     assert_renders <<SASS, <<SCSS
 foo
   +foo-bar($a-b_c: val)
+
   a: blip
 SASS
 foo {
   @include foo-bar($a-b_c: val);
+
   a: blip;
 }
 SCSS
@@ -1096,10 +1145,12 @@ SCSS
     assert_renders <<SASS, <<SCSS
 @function foo()
   $var: 1 + 1
+
   @return $var
 SASS
 @function foo() {
   $var: 1 + 1;
+
   @return $var;
 }
 SCSS
@@ -1139,12 +1190,14 @@ $var1: 12px + 15px
 
 foo
   $var2: flaz(#abcdef)
+
   val: $var1 $var2
 SASS
 $var1: 12px + 15px;
 
 foo {
   $var2: flaz(#abcdef);
+
   val: $var1 $var2;
 }
 SCSS
@@ -1156,12 +1209,14 @@ $var1: 12px + 15px !default
 
 foo
   $var2: flaz(#abcdef) !default
+
   val: $var1 $var2
 SASS
 $var1: 12px + 15px !default;
 
 foo {
   $var2: flaz(#abcdef) !default;
+
   val: $var1 $var2;
 }
 SCSS
@@ -1275,26 +1330,7 @@ SCSS
   end
 
   def test_media_with_expressions
-    assert_sass_to_scss <<SCSS, <<SASS
-$media1: screen;
-$media2: print;
-$var: -webkit-min-device-pixel-ratio;
-$val: 20;
-
-@media \#{$media1} and ($var + "-foo": $val + 5), only \#{$media2} {
-  a: b;
-}
-SCSS
-$media1: screen
-$media2: print
-$var: -webkit-min-device-pixel-ratio
-$val: 20
-
-@media \#{$media1} and ($var + "-foo": $val + 5), only \#{$media2}
-  a: b
-SASS
-
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 $media1: screen
 $media2: print
 $var: -webkit-min-device-pixel-ratio
@@ -1315,14 +1351,14 @@ SCSS
   end
 
   def test_media_with_feature
-    assert_sass_to_scss <<SCSS, <<SASS
+    assert_renders <<SASS, <<SCSS
+@media screen and (-webkit-transform-3d)
+  a: b
+SASS
 @media screen and (-webkit-transform-3d) {
   a: b;
 }
 SCSS
-@media screen and (-webkit-transform-3d)
-  a: b
-SASS
   end
 
   def test_supports_with_expressions
@@ -1331,7 +1367,7 @@ $query: "(feature1: val)"
 $feature: feature2
 $val: val
 
-@supports \#{$query} and ($feature: $val) or (not ($feature + 3: $val + 4))
+@supports (\#{$query} and ($feature: $val)) or (not ($feature + 3: $val + 4))
   foo
     a: b
 SASS
@@ -1339,7 +1375,7 @@ $query: "(feature1: val)";
 $feature: feature2;
 $val: val;
 
-@supports \#{$query} and ($feature: $val) or (not ($feature + 3: $val + 4)) {
+@supports (\#{$query} and ($feature: $val)) or (not ($feature + 3: $val + 4)) {
   foo {
     a: b;
   }
@@ -1448,7 +1484,9 @@ SCSS
 
 div {
   foo: under-scored-fn($under-scored-var + "before\#{$another-under-scored-var}after");
+
   @include under-scored-mixin($passed-arg);
+
   selector-\#{$under-scored-interp}: bold;
 }
 
@@ -1488,7 +1526,9 @@ $color: blue
 =context($class, $color: red)
   .\#{$class}
     background-color: $color
+
     @content
+
     border-color: $color
 
 +context(parent)
@@ -1500,7 +1540,9 @@ $color: blue;
 @mixin context($class, $color: red) {
   .\#{$class} {
     background-color: $color;
+
     @content;
+
     border-color: $color;
   }
 }
@@ -1585,6 +1627,7 @@ foo bar
     baz bang
         baz: bang
         bip: bop
+
     blat: boo
 SASS
 foo bar {
@@ -1592,6 +1635,7 @@ foo bar {
         baz: bang;
         bip: bop;
     }
+
     blat: boo;
 }
 SCSS
@@ -1601,6 +1645,7 @@ foo bar
 	baz bang
 		baz: bang
 		bip: bop
+
 	blat: boo
 SASS
 foo bar {
@@ -1608,6 +1653,7 @@ foo bar {
 		baz: bang;
 		bip: bop;
 	}
+
 	blat: boo;
 }
 SCSS
@@ -1618,6 +1664,7 @@ foo bar {
         baz: bang;
         bip: bop;
     }
+
     blat: boo;
 }
 SCSS
@@ -1625,6 +1672,7 @@ foo bar
   baz bang
     baz: bang
     bip: bop
+
   blat: boo
 SASS
 
@@ -1634,6 +1682,7 @@ foo bar {
 		baz: bang;
 		bip: bop;
 	}
+
 	blat: boo;
 }
 SCSS
@@ -1641,6 +1690,7 @@ foo bar
   baz bang
     baz: bang
     bip: bop
+
   blat: boo
 SASS
 
@@ -1649,6 +1699,7 @@ foo bar
     baz bang
         baz: bang
         bip: bop
+
     blat: boo
 SASS
 foo bar {
@@ -1656,6 +1707,7 @@ foo bar {
     baz: bang;
     bip: bop;
   }
+
   blat: boo;
 }
 SCSS
@@ -1665,6 +1717,7 @@ foo bar
 	baz bang
 		baz: bang
 		bip: bop
+
 	blat: boo
 SASS
 foo bar {
@@ -1672,13 +1725,14 @@ foo bar {
     baz: bang;
     bip: bop;
   }
+
   blat: boo;
 }
 SCSS
   end
 
   def test_extend_with_optional
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 foo
   @extend .bar !optional
 SASS
@@ -1689,7 +1743,7 @@ SCSS
   end
 
   def test_mixin_var_args
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 =foo($args...)
   a: b
 
@@ -1698,6 +1752,7 @@ SCSS
 
 .foo
   +foo($list...)
+
   +bar(1, $list...)
 SASS
 @mixin foo($args...) {
@@ -1710,19 +1765,21 @@ SASS
 
 .foo {
   @include foo($list...);
+
   @include bar(1, $list...);
 }
 SCSS
   end
 
   def test_mixin_var_kwargs
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 =foo($a: b, $c: d)
   a: $a
   c: $c
 
 .foo
   +foo($list..., $map...)
+
   +foo(pos, $list..., $kwd: val, $map...)
 SASS
 @mixin foo($a: b, $c: d) {
@@ -1732,13 +1789,14 @@ SASS
 
 .foo {
   @include foo($list..., $map...);
+
   @include foo(pos, $list..., $kwd: val, $map...);
 }
 SCSS
   end
 
   def test_function_var_args
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 @function foo($args...)
   @return foo
 
@@ -1765,7 +1823,7 @@ SCSS
   end
 
   def test_function_var_kwargs
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 @function foo($a: b, $c: d)
   @return foo
 
@@ -1785,11 +1843,12 @@ SCSS
   end
 
   def test_at_root
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 .foo
   @at-root
     .bar
       a: b
+
     .baz
       c: d
 SASS
@@ -1798,6 +1857,7 @@ SASS
     .bar {
       a: b;
     }
+
     .baz {
       c: d;
     }
@@ -1807,7 +1867,7 @@ SCSS
   end
 
   def test_at_root_with_selector
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 .foo
   @at-root .bar
     a: b
@@ -1821,7 +1881,7 @@ SCSS
   end
 
   def test_at_root_without
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 .foo
   @at-root (without: media rule)
     a: b
@@ -1835,7 +1895,7 @@ SCSS
   end
 
   def test_at_root_with
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 .foo
   @at-root (with: media rule)
     a: b
@@ -1849,7 +1909,7 @@ SCSS
   end
 
   def test_function_var_kwargs_with_list
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 @function foo($a: b, $c: d)
   @return $a, $c
 
@@ -1872,10 +1932,13 @@ SCSS
   0%
     top: 0
     left: 0
+
   30%
     top: 50px
+
   68%, 72%
     left: 50px
+
   100%
     top: 100px
     left: 100%
@@ -1885,12 +1948,15 @@ SASS
     top: 0;
     left: 0;
   }
+
   30% {
     top: 50px;
   }
+
   68%, 72% {
     left: 50px;
   }
+
   100% {
     top: 100px;
     left: 100%;
@@ -1918,12 +1984,13 @@ SCSS
   end
 
   def test_media_query_with_expr
-    assert_scss_to_sass <<SASS, <<SCSS
+    assert_renders <<SASS, <<SCSS
 @media foo and (bar: baz)
   a: b
 SASS
 @media foo and (bar: baz) {
-  a: b; }
+  a: b;
+}
 SCSS
   end
 
@@ -2009,13 +2076,11 @@ foo
     ok: -$foo
     comma: 10px, -$foo
     needs-parens: 10px (-$foo)
-    no-parens: a 50px + 60px b
 SASS
 foo {
     ok: -$foo;
     comma: 10px, -$foo;
     needs-parens: 10px (-$foo);
-    no-parens: a 50px + 60px b;
 }
 SCSS
   end
